@@ -20,10 +20,11 @@ gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 from gi.repository import GObject
 
-import setzer.document.code_folding.code_folding_viewgtk as code_folding_view
 import setzer.document.code_folding.code_folding_controller as code_folding_controller
 import setzer.document.code_folding.code_folding_presenter as code_folding_presenter
+import setzer.document.code_folding.code_folding_gutter_object as code_folding_gutter_object
 from setzer.helpers.observable import Observable
+from setzer.helpers.timer import timer
 
 
 class CodeFolding(Observable):
@@ -33,6 +34,8 @@ class CodeFolding(Observable):
 
         self.is_enabled = False
 
+        self.blocks = list()
+        self.marks_start = dict()
         self.folding_regions = dict()
         self.folding_regions_by_region_id = dict()
         self.maximum_region_id = 0
@@ -41,22 +44,61 @@ class CodeFolding(Observable):
         self.initial_folding_regions_checked_count = 0
 
         self.document = document
-        self.view = code_folding_view.CodeFoldingView()
-        self.presenter = code_folding_presenter.CodeFoldingPresenter(self, self.view)
+        self.gutter_object = code_folding_gutter_object.CodeFoldingGutterObject(self)
+        document.gutter.add_widget(self.gutter_object)
+
+        self.presenter = code_folding_presenter.CodeFoldingPresenter(self)
         self.controller = code_folding_controller.CodeFoldingController(self)
 
-        self.on_buffer_changed(self.document.get_buffer())
+        self.document.content.connect('text_inserted', self.on_text_inserted)
+        self.document.content.connect('text_deleted', self.on_text_deleted)
+        self.document.content.connect('buffer_changed', self.on_buffer_changed)
+
+    def on_text_inserted(self, content, parameter):
+        buffer, location_iter, text, text_length = parameter
+        length = len(text)
+        offset = location_iter.get_offset() + length
+        marks_start = dict()
+        for index, region_id in self.marks_start.items():
+            if index < offset:
+                marks_start[index] = region_id
+            else:
+                index2 = index + length
+                region = self.folding_regions_by_region_id[region_id]
+                region['offset_start'] = index2
+                marks_start[index2] = region_id
+        self.marks_start = marks_start
+
+    def on_text_deleted(self, content, parameter):
+        buffer, start_iter, end_iter = parameter
+        offset_start = start_iter.get_offset()
+        offset_end = end_iter.get_offset()
+        length = offset_end - offset_start
+        marks_start = dict()
+        for index, region_id in self.marks_start.items():
+            if index <= offset_start:
+                marks_start[index] = region_id
+            elif index >= offset_end:
+                index2 = index - length
+                region = self.folding_regions_by_region_id[region_id]
+                region['offset_start'] = index2
+                marks_start[index2] = region_id
+        self.marks_start = marks_start
+
+    def on_buffer_changed(self, content, parameter):
+        if self.is_enabled:
+            self.update_folding_regions()
 
     def enable_code_folding(self):
         self.is_enabled = True
-        GObject.timeout_add(1, self.update_folding_regions)
-        self.add_change_code('is_enabled_changed')
+        self.update_folding_regions()
+        self.gutter_object.show()
 
     def disable_code_folding(self):
         self.is_enabled = False
         for region in self.folding_regions.values():
             self.toggle_folding_region(region, show_region_regardless_of_state=True)
-        self.add_change_code('is_enabled_changed')
+        self.gutter_object.hide()
 
     def toggle_folding_region(self, region, show_region_regardless_of_state=False, hide_region_regardless_of_state=False):
         if show_region_regardless_of_state:
@@ -66,70 +108,84 @@ class CodeFolding(Observable):
         else:
             is_folded = not region['is_folded']
         region['is_folded'] = is_folded
+        if is_folded:
+            self.presenter.hide_region(region)
+        else:
+            self.presenter.show_region(region)
         self.add_change_code('folding_state_changed', region)
 
-    def on_buffer_changed(self, buffer):
-        self.add_change_code('buffer_changed', buffer)
-
     def get_folding_region_by_region_id(self, region_id):
         return self.folding_regions_by_region_id[region_id]
 
+    #@timer
     def update_folding_regions(self):
         folding_regions = dict()
         folding_regions_by_region_id = dict()
-        lines_with_regions = set()
-        blocks = self.document.parser.get_blocks()
-        if blocks == None: return self.is_enabled
+        last_line = -1
+        try:
+            blocks = self.document.content.get_blocks()
+        except AttributeError:
+            return
+        if not self.blocks_changed(blocks): return
+        self.blocks = blocks
 
         for block in blocks:
             if block[1] != None:
-                start_iter = self.document.source_buffer.get_iter_at_offset(block[0])
-                start_iter.forward_to_line_end()
-                line_number = start_iter.get_line()
-                if not line_number in lines_with_regions:
-                    lines_with_regions |= {line_number}
-                    end_iter = self.document.source_buffer.get_iter_at_offset(block[1])
-                    if not end_iter.ends_line():
-                        end_iter.forward_to_line_end()
-                    marks = start_iter.get_marks()
-                    block_in_buffer = False
-                    for mark in marks:
-                        if mark.get_name() != None and mark.get_name().startswith('folding_region_start'):
-                            block_in_buffer = True
-                            region_id = int(mark.get_name()[21:])
-                    if block_in_buffer:
-                        #if region_id in self.folding_regions_by_region_id:
+                if block[2] != last_line:
+                    region_id = self.get_mark_start_at_offset(block[0])
+                    if region_id != None:
                         region_dict = self.get_folding_region_by_region_id(region_id)
-                        region_dict['starting_line'] = start_iter.get_line()
-                        region_dict['ending_line'] = end_iter.get_line()
-                        self.document.source_buffer.move_mark_by_name('folding_region_end_' + str(region_id), end_iter)
+                        region_dict['starting_line'] = block[2]
+                        region_dict['ending_line'] = block[3]
+                        region_dict['offset_end'] = block[1]
                         folding_regions_by_region_id[region_id] = region_dict
                     else:
-                        mark_start = Gtk.TextMark.new('folding_region_start_' + str(self.maximum_region_id), False)
-                        mark_end = Gtk.TextMark.new('folding_region_end_' + str(self.maximum_region_id), False)
-                        self.document.source_buffer.add_mark(mark_start, start_iter)
-                        self.document.source_buffer.add_mark(mark_end, end_iter)
-                        region_dict = {'mark_start': mark_start, 'mark_end': mark_end, 'is_folded': False, 'starting_line': start_iter.get_line(), 'ending_line': end_iter.get_line(), 'id': self.maximum_region_id}
+                        self.add_mark_start(self.maximum_region_id, block[0])
+                        region_dict = {'offset_start': block[0], 'offset_end': block[1], 'is_folded': False, 'starting_line': block[2], 'ending_line': block[3], 'id': self.maximum_region_id}
                         folding_regions_by_region_id[self.maximum_region_id] = region_dict
                         self.maximum_region_id += 1
-                    folding_regions[start_iter.get_line()] = region_dict
+                    folding_regions[block[2]] = region_dict
+                last_line = block[2]
 
-        regions_to_delete = [region_id for region_id in self.folding_regions_by_region_id if region_id not in folding_regions_by_region_id]
-        for region_id in regions_to_delete:
-            region = self.folding_regions_by_region_id[region_id]
-            self.toggle_folding_region(region, show_region_regardless_of_state=True)
-            self.document.source_buffer.delete_mark(region['mark_start'])
-            self.document.source_buffer.delete_mark(region['mark_end'])
+        self.delete_invalid_regions(folding_regions_by_region_id)
 
         self.folding_regions = folding_regions
         self.folding_regions_by_region_id = folding_regions_by_region_id
 
         if not self.initial_folding_done:
             self.initial_folding()
-        else:
-            self.add_change_code('folding_regions_updated')
 
-        return self.is_enabled
+    #@timer
+    def delete_invalid_regions(self, folding_regions_by_region_id):
+        regions_to_delete = [region_id for region_id in self.folding_regions_by_region_id if region_id not in folding_regions_by_region_id]
+        for region_id in regions_to_delete:
+            region = self.folding_regions_by_region_id[region_id]
+            self.toggle_folding_region(region, show_region_regardless_of_state=True)
+            self.delete_mark_start(region['offset_start'])
+
+    def add_mark_start(self, region_id, offset):
+        self.marks_start[offset] = region_id
+
+    def delete_mark_start(self, offset):
+        try:
+            del(self.marks_start[offset])
+        except KeyError:
+            pass
+
+    def get_mark_start_at_offset(self, offset):
+        if offset in self.marks_start:
+            return self.marks_start[offset]
+        return None
+
+    #@timer
+    def blocks_changed(self, blocks):
+        blocks_old = self.blocks
+        if len(blocks) != len(blocks_old):
+            return True
+        for block_old, block_new in zip(blocks_old, blocks):
+            if block_old[0] != block_new[0] or block_old[1] != block_new[1]:
+                return True
+        return False
 
     def get_folded_regions(self):
         folded_regions = list()
@@ -141,6 +197,7 @@ class CodeFolding(Observable):
     def set_initial_folded_regions(self, folded_regions):
         self.initial_folded_regions = folded_regions
         self.initial_folded_regions_set = True
+        self.initial_folding()
 
     def initial_folding(self):
         self.initial_folding_regions_checked_count += 1
@@ -151,7 +208,7 @@ class CodeFolding(Observable):
                         if region['ending_line'] == self.folding_regions[region['starting_line']]['ending_line']:
                             folding_region = self.folding_regions[region['starting_line']]
                             self.toggle_folding_region(folding_region, hide_region_regardless_of_state=True)
-            self.initial_folding_done = True
+                self.initial_folding_done = True
         if self.initial_folding_regions_checked_count >= 3:
             self.initial_folding_done = True
 
