@@ -17,6 +17,8 @@
 
 import os.path
 
+import setzer.document.content.content as content
+import setzer.document.state_manager.state_manager as state_manager
 import setzer.document.document_controller as document_controller
 import setzer.document.document_presenter as document_presenter
 import setzer.document.context_menu.context_menu as context_menu
@@ -27,17 +29,24 @@ import setzer.document.shortcutsbar.shortcutsbar_presenter as shortcutsbar_prese
 import setzer.document.spellchecker.spellchecker as spellchecker
 import setzer.document.gutter.gutter as gutter
 import setzer.document.line_numbers.line_numbers as line_numbers
+import setzer.document.preview.preview as preview
+import setzer.document.build_system.build_system as build_system
+import setzer.document.build_widget.build_widget as build_widget
+import setzer.document.autocomplete.autocomplete as autocomplete
+import setzer.document.code_folding.code_folding as code_folding
+import setzer.document.preview.preview as preview
 from setzer.helpers.observable import Observable
 from setzer.app.service_locator import ServiceLocator
 
 
 class Document(Observable):
 
-    def __init__(self):
+    def __init__(self, document_type):
         Observable.__init__(self)
 
         self.font_manager = ServiceLocator.get_font_manager()
 
+        self.document_type = document_type
         self.displayname = ''
         self.filename = None
         self.save_date = None
@@ -47,7 +56,8 @@ class Document(Observable):
         self.is_root = False
         self.root_is_set = False
 
-    def init_main_submodules(self):
+        self.content = content.Content(self.document_type)
+
         self.view = document_view.DocumentView(self)
         self.gutter = gutter.Gutter(self, self.view)
         self.search = search.Search(self, self.view, self.view.search_bar)
@@ -61,13 +71,22 @@ class Document(Observable):
 
         self.line_numbers = line_numbers.LineNumbers(self, self.view)
 
-    def update_syntax_scheme(self):
-        self.content.update_syntax_scheme()
+        self.state_manager = state_manager.StateManager(self)
+
+    def add_latex_only_modules(self):
+        self.preview = preview.Preview(self)
+        self.autocomplete = autocomplete.Autocomplete(self, self.view)
+        self.build_system = build_system.BuildSystem(self)
+        self.build_widget = build_widget.BuildWidget(self)
+        self.code_folding = code_folding.CodeFolding(self)
 
     def set_dark_mode(self, dark_mode):
         self.dark_mode = dark_mode
         self.content.set_use_dark_scheme(dark_mode)
 
+    def get_document_type(self):
+        return self.document_type
+
     def set_filename(self, filename):
         if filename == None:
             self.filename = filename
@@ -106,9 +125,6 @@ class Document(Observable):
     def set_last_activated(self, date):
         self.last_activated = date
 
-    def get_modified(self):
-        return self.content.get_modified()
-
     def populate_from_filename(self):
         if self.filename == None: return False
         if not os.path.isfile(self.filename):
@@ -118,8 +134,8 @@ class Document(Observable):
 
         with open(self.filename) as f:
             text = f.read()
-        self.initially_set_text(text)
-        self.place_cursor(0, 0)
+        self.content.initially_set_text(text)
+        self.content.place_cursor(0, 0)
         self.content.scroll_cursor_onscreen()
         self.update_save_date()
         return True
@@ -128,7 +144,7 @@ class Document(Observable):
         if self.filename == None: return False
         if self.content == None: return False
 
-        text = self.get_text()
+        text = self.content.get_all_text()
         if text == None: return False
 
         dirname = os.path.dirname(self.filename)
@@ -150,76 +166,30 @@ class Document(Observable):
     def get_deleted_on_disk(self):
         return not os.path.isfile(self.filename)
 
-    def initially_set_text(self, text):
-        self.content.initially_set_text(text)
-
-    def get_text(self):
-        return self.content.get_all_text()
-
-    def get_text_after_offset(self, offset):
-        return self.content.get_text_after_offset(offset)
-
-    def get_selected_text(self):
-        return self.content.get_selected_text()
-
-    def get_line_at_cursor(self):
-        return self.content.get_line_at_cursor()
-
-    def get_char_at_cursor(self):
-        return self.content.get_char_at_cursor()
-
-    def get_line(self, line_number):
-        return self.content.get_line(line_number)
-
-    def get_current_line_number(self):
-        return self.content.get_current_line_number()
-
-    def is_empty(self):
-        return self.content.is_empty()
-
-    def place_cursor(self, line_number, offset=0):
-        self.content.place_cursor(line_number, offset)
-
-    def get_cursor_offset(self):
-        return self.content.get_cursor_offset()
-
-    def get_cursor_line_offset(self):
-        return self.content.get_cursor_line_offset()
-
     def cursor_inside_latex_command_or_at_end(self):
-        current_word = self.get_latex_command_at_cursor()
+        current_word = self.content.get_latex_command_at_cursor()
         if ServiceLocator.get_regex_object(r'\\(\w*(?:\*){0,1})').fullmatch(current_word):
             return True
         return False
 
     def cursor_at_latex_command_end(self):
-        current_word = self.get_latex_command_at_cursor()
+        current_word = self.content.get_latex_command_at_cursor()
         if ServiceLocator.get_regex_object(r'\\(\w*(?:\*){0,1})').fullmatch(current_word):
             return self.content.cursor_ends_word()
         return False
 
-    def insert_before_document_end(self, text):
-        self.content.insert_before_document_end(text)
+    def set_root_state(self, is_root, root_is_set):
+        self.is_root = is_root
+        self.root_is_set = root_is_set
+        self.add_change_code('is_root_changed', is_root)
 
-    def insert_text(self, line_number, offset, text, indent_lines=True):
-        self.content.insert_text(line_number, offset, text, indent_lines)
+    def is_latex_document(self):
+        return self.document_type == 'latex'
 
-    def insert_text_at_cursor(self, text, indent_lines=True, select_dot=True):
-        self.content.insert_text_at_cursor(text, indent_lines, select_dot)
+    def is_bibtex_document(self):
+        return self.document_type == 'bibtex'
 
-    def insert_template(self, template_start, template_end):
-        self.content.insert_template(template_start, template_end)
-
-    def replace_range(self, offset, length, text, indent_lines=True, select_dot=True):
-        self.content.replace_range_by_offset_and_length(offset, length, text, indent_lines, select_dot)
-
-    def insert_before_after(self, before, after):
-        self.content.insert_before_after(before, after)
-
-    def add_backslash_with_space(self):
-        self.content.add_backslash_with_space()
-
-    def autoadd_latex_brackets(self, char):
-        self.content.autoadd_latex_brackets(char)
+    def get_is_root(self):
+        return self.is_root
 
 
