@@ -36,7 +36,7 @@ class DocumentController(object):
         self.document = document
         self.view = document_view
 
-        self.forward_sync_manager = ServiceLocator.get_forward_sync_manager()
+        self.workspace = ServiceLocator.get_workspace()
 
         self.view.source_view.connect('key-press-event', self.on_keypress)
         self.view.source_view.connect('button-press-event', self.on_buttonpress)
@@ -48,10 +48,12 @@ class DocumentController(object):
     '''
 
     def on_buttonpress(self, widget, event, data=None):
+        modifiers = Gtk.accelerator_get_default_mod_mask()
+
         if event.type == Gdk.EventType.BUTTON_PRESS:
-            if event.state == Gdk.ModifierType.CONTROL_MASK:
-                if self.forward_sync_manager.can_sync:
-                    GLib.idle_add(self.forward_sync_manager.forward_sync, self.document)
+            if event.state & modifiers == Gdk.ModifierType.CONTROL_MASK:
+                if self.workspace.can_sync:
+                    GLib.idle_add(self.workspace.forward_sync, self.document)
         return False
 
     def on_keypress(self, widget, event, data=None):
@@ -69,22 +71,22 @@ class DocumentController(object):
 
         if not keypress_handled and event.keyval == Gdk.keyval_from_name('c'):
             if event.state & modifiers == Gdk.ModifierType.CONTROL_MASK:
-                self.document.copy()
+                self.document.content.copy()
                 return True
 
         if not keypress_handled and event.keyval == Gdk.keyval_from_name('x'):
             if event.state & modifiers == Gdk.ModifierType.CONTROL_MASK:
-                self.document.cut()
+                self.document.content.cut()
                 return True
 
         if not keypress_handled and event.keyval == Gdk.keyval_from_name('v'):
             if event.state & modifiers == Gdk.ModifierType.CONTROL_MASK:
-                self.document.paste()
+                self.document.content.paste()
                 return True
 
         if not keypress_handled and event.keyval in tab_keyvals:
             if event.state & modifiers == 0:
-                buffer = self.document.get_buffer()
+                buffer = self.document.content.source_buffer
                 insert = buffer.get_iter_at_mark(buffer.get_insert())
                 insert.forward_chars(1)
                 limit_iter = insert.copy()
@@ -94,31 +96,31 @@ class DocumentController(object):
                 if result != None:
                     buffer.place_cursor(result[0])
                     buffer.select_range(result[0], result[1])
-                    self.document.source_buffer.scroll_iter_onscreen(result[1])
+                    self.document.content.scroll_cursor_onscreen()
                     return True
                 
                 insert.backward_chars(1)
                 result = insert.forward_search('•', Gtk.TextSearchFlags.VISIBLE_ONLY, limit_iter)
                 if result != None:
                     buffer.select_range(result[0], result[1])
-                    self.document.source_buffer.scroll_iter_onscreen(result[1])
+                    self.document.content.scroll_cursor_onscreen()
                     return True
             elif event.state & modifiers == Gdk.ModifierType.SHIFT_MASK:
-                buffer = self.document.get_buffer()
+                buffer = self.document.content.source_buffer
                 insert = buffer.get_iter_at_mark(buffer.get_insert())
                 limit_iter = insert.copy()
                 limit_iter.backward_lines(3)
                 result = insert.backward_search('•', Gtk.TextSearchFlags.VISIBLE_ONLY, limit_iter)
                 if result != None:
                     buffer.select_range(result[0], result[1])
-                    self.document.source_buffer.scroll_iter_onscreen(result[1])
+                    self.document.content.scroll_cursor_onscreen()
                     return True
 
                 insert.forward_chars(1)
                 result = insert.backward_search('•', Gtk.TextSearchFlags.VISIBLE_ONLY, limit_iter)
                 if result != None:
                     buffer.select_range(result[0], result[1])
-                    self.document.source_buffer.scroll_iter_onscreen(result[1])
+                    self.document.content.scroll_cursor_onscreen()
                     return True
         return False
 
@@ -128,14 +130,14 @@ class DocumentController(object):
         if self.document.get_deleted_on_disk():
             DialogLocator.get_dialog('document_deleted_on_disk').run(self.document)
             self.document.deleted_on_disk_dialog_shown_after_last_save = True
-            self.document.source_buffer.set_modified(True)
+            self.document.content.set_modified(True)
             return True
         if self.document.get_changed_on_disk():
             if DialogLocator.get_dialog('document_changed_on_disk').run(self.document):
                 self.document.populate_from_filename()
-                self.document.source_buffer.set_modified(False)
+                self.document.content.set_modified(False)
             else:
-                self.document.source_buffer.set_modified(True)
+                self.document.content.set_modified(True)
             self.document.update_save_date()
         return self.continue_save_date_loop
 
