@@ -226,7 +226,7 @@ class Actions(object):
             self.save_action.set_enabled(False)
             self.save_all_action.set_enabled(False)
         else:
-            if document.get_modified():
+            if document.content.get_modified():
                 self.save_action.set_enabled(True)
             elif document.get_filename() == None:
                 self.save_action.set_enabled(True)
@@ -270,10 +270,14 @@ class Actions(object):
         self.close_build_log_action.set_enabled(value)
 
     def on_new_latex_document_action_activated(self, action=None, parameter=None):
-        self.workspace.create_latex_document(activate=True)
+        document = self.workspace.create_latex_document()
+        self.workspace.add_document(document)
+        self.workspace.set_active_document(document)
 
     def on_new_bibtex_document_action_activated(self, action=None, parameter=None):
-        self.workspace.create_bibtex_document(activate=True)
+        document = self.workspace.create_bibtex_document()
+        self.workspace.add_document(document)
+        self.workspace.set_active_document(document)
 
     def on_open_document_dialog_action_activated(self, action=None, parameter=None):
         filename = DialogLocator.get_dialog('open_document').run()
@@ -390,7 +394,7 @@ class Actions(object):
 
     def on_close_document_clicked(self, action=None, parameter=None):
         document = self.workspace.get_active_document()
-        if document.get_modified():
+        if document.content.get_modified():
             dialog = DialogLocator.get_dialog('close_confirmation')
             not_save_to_close = dialog.run([document])['not_save_to_close_documents']
             if document not in not_save_to_close:
@@ -400,18 +404,19 @@ class Actions(object):
 
     @_assert_has_active_document
     def insert_before_after(self, action, parameter):
-        self.workspace.get_active_document().insert_before_after(parameter[0], parameter[1])
-        self.workspace.get_active_document().content.scroll_cursor_onscreen()
+        active_document = self.workspace.get_active_document()
+        active_document.content.insert_before_after(parameter[0], parameter[1])
+        active_document.content.scroll_cursor_onscreen()
 
     @_assert_has_active_document
     def insert_symbol(self, action, parameter):
-        self.workspace.get_active_document().insert_text_at_cursor(parameter[0])
+        self.workspace.get_active_document().content.insert_text_at_cursor(parameter[0])
         self.workspace.get_active_document().content.scroll_cursor_onscreen()
 
     @_assert_has_active_document
     def insert_before_document_end(self, action, parameter):
         document = self.workspace.get_active_document()
-        document.insert_before_document_end(parameter[0])
+        document.content.insert_before_document_end(parameter[0])
         document.content.scroll_cursor_onscreen()
 
     @_assert_has_active_document
@@ -439,12 +444,13 @@ class Actions(object):
         if parameter == None: return
         document = self.workspace.get_active_document()
         if document.is_latex_document():
-            document.add_packages(parameter)
+            document.content.add_packages(parameter)
+            document.content.scroll_cursor_onscreen()
 
     @_assert_has_active_document
     def comment_uncomment(self, action, parameter=None):
         document = self.workspace.get_active_document()
-        document.comment_uncomment()
+        document.content.comment_uncomment()
 
     @_assert_has_active_document
     def start_create_new_bibtex_entry_dialog(self, action, parameter=None):
@@ -475,7 +481,7 @@ class Actions(object):
 
     def close_build_log(self, action, parameter=''):
         self.workspace.set_show_build_log(False)
-    
+
     def on_spellchecking_toggle_toggled(self, action, parameter=None):
         new_state = not action.get_state().get_boolean()
         action.set_state(GLib.Variant.new_boolean(new_state))
