@@ -53,23 +53,12 @@ class BuildLogController(object):
             item_num = max(0, min(int(event.y // self.view.line_height), len(self.build_log.items) - 1))
             item = self.build_log.items[item_num]
 
-            if item[2] == self.build_log.document.get_filename():
+            if item[2] != None:
+                self.build_log.workspace.open_document_by_filename(item[2])
                 line_number = item[3] - 1
                 if line_number >= 0:
-                    self.build_log.document.place_cursor(line_number)
-                    self.build_log.document.content.scroll_cursor_onscreen()
-                    self.build_log.document.view.source_view.grab_focus()
-            else:
-                if item[2] != None:
-                    document_candidate = self.build_log.workspace.get_document_by_filename(item[2])
-                    if document_candidate != None:
-                        self.build_log.workspace.set_active_document(document_candidate)
-                    else:
-                        self.build_log.workspace.create_document_from_filename(item[2], True)
-                    line_number = item[3] - 1
-                    if line_number >= 0:
-                        self.build_log.workspace.active_document.place_cursor(item[3] - 1)
-                        self.build_log.workspace.active_document.content.scroll_cursor_onscreen()
-                        self.build_log.workspace.active_document.view.source_view.grab_focus()
+                    self.build_log.workspace.active_document.content.place_cursor(item[3] - 1)
+                    self.build_log.workspace.active_document.content.scroll_cursor_onscreen()
+                    self.build_log.workspace.active_document.view.source_view.grab_focus()
 
 
