@@ -24,13 +24,14 @@ from gi.repository import GLib
 
 import setzer.workspace.build_log.build_log_viewgtk as build_log_view
 import setzer.workspace.headerbar.headerbar_viewgtk as headerbar_view
-import setzer.workspace.latex_shortcutsbar.latex_shortcutsbar_viewgtk as latex_shortcutsbar_view
-import setzer.workspace.bibtex_shortcutsbar.bibtex_shortcutsbar_viewgtk as bibtex_shortcutsbar_view
-import setzer.workspace.others_shortcutsbar.others_shortcutsbar_viewgtk as others_shortcutsbar_view
+import setzer.workspace.shortcutsbar.latex_shortcutsbar.latex_shortcutsbar_viewgtk as latex_shortcutsbar_view
+import setzer.workspace.shortcutsbar.bibtex_shortcutsbar.bibtex_shortcutsbar_viewgtk as bibtex_shortcutsbar_view
+import setzer.workspace.shortcutsbar.others_shortcutsbar.others_shortcutsbar_viewgtk as others_shortcutsbar_view
 import setzer.workspace.preview_panel.preview_panel_viewgtk as preview_panel_view
 import setzer.workspace.help_panel.help_panel_viewgtk as help_panel_view
 import setzer.workspace.sidebar.sidebar_viewgtk as sidebar_view
 import setzer.workspace.welcome_screen.welcome_screen_viewgtk as welcome_screen_view
+import setzer.widgets.animated_paned.animated_paned as animated_paned
 from setzer.app.service_locator import ServiceLocator
 
 import os.path
@@ -59,9 +60,9 @@ class MainWindow(Gtk.ApplicationWindow):
         self.latex_notebook.set_show_border(False)
         self.latex_notebook.set_scrollable(True)
         self.latex_notebook.set_size_request(550, -1)
-        self.latex_shortcuts_bar = latex_shortcutsbar_view.LaTeXShortcutsBar()
+        self.latex_shortcutsbar = latex_shortcutsbar_view.LaTeXShortcutsbar()
         self.latex_notebook_wrapper = Gtk.VBox()
-        self.latex_notebook_wrapper.pack_start(self.latex_shortcuts_bar, False, False, 0)
+        self.latex_notebook_wrapper.pack_start(self.latex_shortcutsbar, False, False, 0)
         self.latex_notebook_wrapper.pack_start(self.latex_notebook, True, True, 0)
 
         # bibtex notebook
@@ -70,9 +71,9 @@ class MainWindow(Gtk.ApplicationWindow):
         self.bibtex_notebook.set_show_border(False)
         self.bibtex_notebook.set_scrollable(True)
         self.bibtex_notebook.set_size_request(550, -1)
-        self.bibtex_shortcuts_bar = bibtex_shortcutsbar_view.BibTeXShortcutsBar()
+        self.bibtex_shortcutsbar = bibtex_shortcutsbar_view.BibTeXShortcutsbar()
         self.bibtex_notebook_wrapper = Gtk.VBox()
-        self.bibtex_notebook_wrapper.pack_start(self.bibtex_shortcuts_bar, False, False, 0)
+        self.bibtex_notebook_wrapper.pack_start(self.bibtex_shortcutsbar, False, False, 0)
         self.bibtex_notebook_wrapper.pack_start(self.bibtex_notebook, True, True, 0)
 
         # others notebook
@@ -81,16 +82,14 @@ class MainWindow(Gtk.ApplicationWindow):
         self.others_notebook.set_show_border(False)
         self.others_notebook.set_scrollable(True)
         self.others_notebook.set_size_request(550, -1)
-        self.others_shortcuts_bar = others_shortcutsbar_view.OthersShortcutsBar()
+        self.others_shortcutsbar = others_shortcutsbar_view.OthersShortcutsbar()
         self.others_notebook_wrapper = Gtk.VBox()
-        self.others_notebook_wrapper.pack_start(self.others_shortcuts_bar, False, False, 0)
+        self.others_notebook_wrapper.pack_start(self.others_shortcutsbar, False, False, 0)
         self.others_notebook_wrapper.pack_start(self.others_notebook, True, True, 0)
 
         # build log
         self.build_log = build_log_view.BuildLogView()
-        self.build_log_paned = Gtk.VPaned()
-        self.build_log_paned.pack1(self.latex_notebook_wrapper, True, False)
-        self.build_log_paned.pack2(self.build_log, False, True)
+        self.build_log_paned = animated_paned.AnimatedVPaned(self.latex_notebook_wrapper, self.build_log, False)
         self.build_log_visible = None
 
         # preview
@@ -103,7 +102,6 @@ class MainWindow(Gtk.ApplicationWindow):
 
         # sidebar
         self.sidebar = sidebar_view.Sidebar()
-        self.sidebar_visible = None
 
         # paneds
         self.preview_paned_overlay = Gtk.Overlay()
@@ -111,13 +109,9 @@ class MainWindow(Gtk.ApplicationWindow):
         self.preview_help_stack = Gtk.Stack()
         self.preview_help_stack.add_named(self.preview_panel, 'preview')
         self.preview_help_stack.add_named(self.help_panel, 'help')
-        self.preview_paned = Gtk.HPaned()
-        self.preview_paned.pack1(self.build_log_paned, True, False)
-        self.preview_paned.pack2(self.preview_help_stack, False, True)
+        self.preview_paned = animated_paned.AnimatedHPaned(self.build_log_paned, self.preview_help_stack, False)
         self.preview_paned_overlay.add(self.preview_paned)
-        self.sidebar_paned = Gtk.HPaned()
-        self.sidebar_paned.pack1(self.sidebar, False, True)
-        self.sidebar_paned.pack2(self.preview_paned_overlay, True, False)
+        self.sidebar_paned = animated_paned.AnimatedHPaned(self.sidebar, self.preview_paned_overlay, True)
         self.sidebar_paned.get_style_context().add_class('sidebar_paned')
 
         # welcome screen
@@ -134,10 +128,9 @@ class MainWindow(Gtk.ApplicationWindow):
         self.css_provider = Gtk.CssProvider()
         resources_path = ServiceLocator.get_resources_path()
         self.css_provider.load_from_path(os.path.join(resources_path, 'style_gtk.css'))
-        self.style_context = Gtk.StyleContext()
-        self.style_context.add_provider_for_screen(self.get_screen(), self.css_provider, Gtk.STYLE_PROVIDER_PRIORITY_USER)
+        Gtk.StyleContext.add_provider_for_screen(self.get_screen(), self.css_provider, Gtk.STYLE_PROVIDER_PRIORITY_USER)
 
         self.css_provider_font_size = Gtk.CssProvider()
-        self.style_context.add_provider_for_screen(self.get_screen(), self.css_provider_font_size, Gtk.STYLE_PROVIDER_PRIORITY_USER)
+        Gtk.StyleContext.add_provider_for_screen(self.get_screen(), self.css_provider_font_size, Gtk.STYLE_PROVIDER_PRIORITY_USER)
 
 
